@@ -2,12 +2,8 @@ use 5.008001;
 use strict;
 use warnings;
 
-package XML::Builder;
-$XML::Builder::VERSION = '0.903';
-# ABSTRACT: programmatic XML generation, conveniently
-
 package XML::Builder::Util;
-$XML::Builder::Util::VERSION = '0.903';
+$XML::Builder::Util::VERSION = '0.904';
 use Scalar::Util ();
 use Encode ();
 use Carp::Clan '^XML::Builder(?:\z|::)';
@@ -37,6 +33,8 @@ sub $new_method { \$_[0]->$class_method->new( builder => \@_ ) }
 #######################################################################
 
 package XML::Builder;
+$XML::Builder::VERSION = '0.904';
+# ABSTRACT: programmatic XML generation, conveniently
 
 use Object::Tiny::Lvalue qw( nsmap default_ns encoding );
 
@@ -226,7 +224,7 @@ sub stringify {
 #######################################################################
 
 package XML::Builder::NS;
-$XML::Builder::NS::VERSION = '0.903';
+$XML::Builder::NS::VERSION = '0.904';
 use Object::Tiny::Lvalue qw( builder uri prefix qname_for_localname );
 use overload '""' => 'uri', fallback => 1;
 
@@ -263,7 +261,7 @@ sub factory { bless \shift, 'XML::Builder::NS::QNameFactory' }
 #######################################################################
 
 package XML::Builder::NS::QNameFactory;
-$XML::Builder::NS::QNameFactory::VERSION = '0.903';
+$XML::Builder::NS::QNameFactory::VERSION = '0.904';
 sub AUTOLOAD { my $self = shift; $$self->qname( ( our $AUTOLOAD =~ /.*::(.*)/ ), @_ ) }
 sub _qname   { my $self = shift; $$self->qname(                                  @_ ) }
 sub DESTROY  {}
@@ -271,13 +269,13 @@ sub DESTROY  {}
 #######################################################################
 
 package XML::Builder::Fragment::Role;
-$XML::Builder::Fragment::Role::VERSION = '0.903';
+$XML::Builder::Fragment::Role::VERSION = '0.904';
 sub depends_ns_scope { 1 }
 
 #######################################################################
 
 package XML::Builder::Fragment;
-$XML::Builder::Fragment::VERSION = '0.903';
+$XML::Builder::Fragment::VERSION = '0.904';
 use parent -norequire => 'XML::Builder::Fragment::Role';
 
 use Object::Tiny::Lvalue qw( builder content );
@@ -346,7 +344,7 @@ sub flatten {
 #######################################################################
 
 package XML::Builder::Fragment::Unsafe;
-$XML::Builder::Fragment::Unsafe::VERSION = '0.903';
+$XML::Builder::Fragment::Unsafe::VERSION = '0.904';
 use parent -norequire => 'XML::Builder::Fragment';
 
 sub depends_ns_scope { 0 }
@@ -368,7 +366,7 @@ sub flatten { shift }
 #######################################################################
 
 package XML::Builder::Fragment::QName;
-$XML::Builder::Fragment::QName::VERSION = '0.903';
+$XML::Builder::Fragment::QName::VERSION = '0.904';
 use Object::Tiny::Lvalue qw( builder ns name as_qname as_attr_qname as_clarkname as_string );
 
 use parent -norequire => 'XML::Builder::Fragment';
@@ -445,7 +443,7 @@ sub foreach {
 #######################################################################
 
 package XML::Builder::Fragment::Tag;
-$XML::Builder::Fragment::Tag::VERSION = '0.903';
+$XML::Builder::Fragment::Tag::VERSION = '0.904';
 use parent -norequire => 'XML::Builder::Fragment';
 use Object::Tiny::Lvalue qw( qname attr );
 
@@ -483,7 +481,7 @@ sub flatten { shift }
 #######################################################################
 
 package XML::Builder::Fragment::Root;
-$XML::Builder::Fragment::Root::VERSION = '0.903';
+$XML::Builder::Fragment::Root::VERSION = '0.904';
 use parent -norequire => 'XML::Builder::Fragment::Tag';
 use overload '""' => 'as_string', fallback => 1;
 
@@ -507,7 +505,7 @@ sub as_string {
 #######################################################################
 
 package XML::Builder::Fragment::Document;
-$XML::Builder::Fragment::Document::VERSION = '0.903';
+$XML::Builder::Fragment::Document::VERSION = '0.904';
 use parent -norequire => 'XML::Builder::Fragment';
 use overload '""' => 'as_string', fallback => 1;
 
@@ -556,11 +554,11 @@ __END__
 
 =head1 NAME
 
-XML::Builder - programmatic XML generation, conveniently
+XML::Builder::Util - programmatic XML generation, conveniently
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 DESCRIPTION
 
